@@ -62,6 +62,12 @@ formTools = {
                 area.insertBefore(source_copy, area.children[area.children.length-2]);
             }
 
+            jQuery('#' + old_id + '-modal .selectpicker').each(function() {
+                if ( this.tomselect ) {
+                    this.tomselect?.destroy();
+                    this.classList.remove('tomselected', 'ts-hidden-accessible');
+                }
+            });
             const modal_copy = jQuery('#' + old_id + '-modal').clone(true);
             jQuery('div.modal-wrapper:visible').append(modal_copy);
             modal_copy.attr('id', source_copy.id + '-modal' );
@@ -73,9 +79,8 @@ formTools = {
                 const input = jQuery(this);
                 input.attr('name', input.attr('name').replace(/^template-/, ''));
             });
-            modal_copy.find('select:not(.combobox)').selectpicker();
 
-            modal_copy.find('.custom-checkbox, .custom-radio').each(function() {
+            modal_copy.find('.form-check').each(function() {
                 const input = jQuery(this).find('input');
                 const label = jQuery(this).find('label');
                 label.attr('for', source_copy.id + label.attr('for').replace(/^template-/, ''));
@@ -84,6 +89,8 @@ formTools = {
 
             // combobox dropdown icon doesn't work after drag&drop, hide it for now
             modal_copy.find('.combobox-container .input-group-append').hide();
+            modal_copy.find('select').addClass('selectpicker');
+            initializeSelectElements(modal_copy.get(0));
         }
         formTools.submit();
     },
